@@ -5,11 +5,17 @@ loglik.dcc <- function (param, dvar, model) {
     Id <- diag(ndim)
     npar <- length(param)
     dcc.param <- param[(npar-1):npar]
-    param <- c(param[1:(npar-2)], rep(0, ndim*(ndim - 1)/2))
-    para.mat <- p.mat(param, model, ndim)
-    a <- para.mat$a
-    A <- para.mat$A
-    B <- para.mat$B
+
+      if(model=="diagonal"){                       # for the diagonal vector GARCH equation
+         a <- param[1:ndim]                         # constant in variance
+         A <- diag(param[(ndim+1):(2*ndim)])        # ARCH parameter
+         B <- diag(param[(2*ndim+1):(3*ndim)])      # GARCH parameter
+      } else if(model=="extended"){                # for the extended vector GARCH equation
+         a <- param[1:ndim]
+         A <- matrix(param[(ndim+1):(ndim^2+ndim)], ndim, ndim)
+         B <- matrix(param[(ndim^2+ndim+1):(2*ndim^2+ndim)], ndim, ndim)
+      } 
+
     h <- vector.garch(dvar, a, A, B)
     z <- dvar/sqrt(h)
     DCC <- dcc.est(z, dcc.param)$DCC
